summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorruki <[email protected]>2026-02-28 23:13:31 +0800
committerruki <[email protected]>2026-02-28 23:13:31 +0800
commit0b39869ef9dca5d0f35119540a04358d6a37d8f3 (patch)
tree99f19ad5179e985a10cd6ed7566f7315d89ce15b
parenta4b8b3e4d3725ada922dbd62d48f833a83746dcb (diff)
rename TARGETNAME to TARGET_NAME
-rw-r--r--xmake/actions/create/template.lua2
-rw-r--r--xmake/modules/target/action/install/cmake_importfiles.lua2
-rw-r--r--xmake/scripts/cmake_importfiles/xxxConfig.cmake4
-rw-r--r--xmake/scripts/cmake_importfiles/xxxTargets-debug.cmake10
-rw-r--r--xmake/scripts/cmake_importfiles/xxxTargets-release.cmake10
-rw-r--r--xmake/scripts/cmake_importfiles/xxxTargets.cmake10
-rw-r--r--xmake/templates/c++/console/xmake.lua2
-rw-r--r--xmake/templates/c++/module.binary/xmake.lua2
-rw-r--r--xmake/templates/c++/module.shared/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.console/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.quickapp/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.quickapp_static/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.shared/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.static/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.widgetapp/xmake.lua2
-rw-r--r--xmake/templates/c++/qt.widgetapp_static/xmake.lua2
-rw-r--r--xmake/templates/c++/shared/xmake.lua2
-rw-r--r--xmake/templates/c++/static/xmake.lua2
-rw-r--r--xmake/templates/c++/wxwidgets/xmake.lua2
-rw-r--r--xmake/templates/c++/xmake.cli/src/lni/main.cpp2
-rw-r--r--xmake/templates/c++/xmake.cli/xmake.lua2
-rw-r--r--xmake/templates/c/console/xmake.lua2
-rw-r--r--xmake/templates/c/module.binary/xmake.lua2
-rw-r--r--xmake/templates/c/module.shared/xmake.lua2
-rw-r--r--xmake/templates/c/shared/xmake.lua2
-rw-r--r--xmake/templates/c/static/xmake.lua2
-rw-r--r--xmake/templates/c/xmake.cli/src/lni/main.c2
-rw-r--r--xmake/templates/c/xmake.cli/xmake.lua2
-rw-r--r--xmake/templates/cuda/console/xmake.lua2
-rw-r--r--xmake/templates/cuda/shared/xmake.lua2
-rw-r--r--xmake/templates/cuda/static/xmake.lua2
-rw-r--r--xmake/templates/dlang/console/xmake.lua2
-rw-r--r--xmake/templates/dlang/shared/xmake.lua6
-rw-r--r--xmake/templates/dlang/static/xmake.lua6
-rw-r--r--xmake/templates/fortran/console/xmake.lua2
-rw-r--r--xmake/templates/fortran/shared/xmake.lua6
-rw-r--r--xmake/templates/fortran/static/xmake.lua6
-rw-r--r--xmake/templates/go/console/xmake.lua2
-rw-r--r--xmake/templates/go/static/xmake.lua2
-rw-r--r--xmake/templates/kotlin/console/xmake.lua2
-rw-r--r--xmake/templates/kotlin/shared/xmake.lua2
-rw-r--r--xmake/templates/kotlin/static/xmake.lua2
-rw-r--r--xmake/templates/nim/console/xmake.lua2
-rw-r--r--xmake/templates/nim/shared/xmake.lua6
-rw-r--r--xmake/templates/nim/static/xmake.lua6
-rw-r--r--xmake/templates/objc++/console/xmake.lua2
-rw-r--r--xmake/templates/objc++/xcode.bundle/xmake.lua2
-rw-r--r--xmake/templates/objc++/xcode.framework/xmake.lua2
-rw-r--r--xmake/templates/objc/console/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.bundle/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.framework/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.iosapp/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.iosapp_with_framework/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.macapp/xmake.lua2
-rw-r--r--xmake/templates/objc/xcode.macapp_with_framework/xmake.lua2
-rw-r--r--xmake/templates/pascal/console/xmake.lua2
-rw-r--r--xmake/templates/pascal/shared/xmake.lua2
-rw-r--r--xmake/templates/rust/console/xmake.lua2
-rw-r--r--xmake/templates/rust/shared/xmake.lua2
-rw-r--r--xmake/templates/rust/static/xmake.lua2
-rw-r--r--xmake/templates/swift/console/xmake.lua2
-rw-r--r--xmake/templates/vala/console/xmake.lua2
-rw-r--r--xmake/templates/vala/shared/xmake.lua2
-rw-r--r--xmake/templates/vala/static/xmake.lua2
-rw-r--r--xmake/templates/zig/console/xmake.lua2
-rw-r--r--xmake/templates/zig/shared/xmake.lua6
-rw-r--r--xmake/templates/zig/static/xmake.lua6
67 files changed, 96 insertions, 96 deletions
diff --git a/xmake/actions/create/template.lua b/xmake/actions/create/template.lua
index 2e27d8459..ffba50f60 100644
--- a/xmake/actions/create/template.lua
+++ b/xmake/actions/create/template.lua
@@ -25,7 +25,7 @@ import("core.language.language")
-- some builtin template variables in xmake.lua
function builtinvars(targetname)
- return {TARGETNAME = targetname,
+ return {TARGET_NAME = targetname,
FAQ = function() return io.readfile(path.join(os.programdir(), "scripts", "faq.lua")) end}
end
diff --git a/xmake/modules/target/action/install/cmake_importfiles.lua b/xmake/modules/target/action/install/cmake_importfiles.lua
index c9c454554..fa00a1ef8 100644
--- a/xmake/modules/target/action/install/cmake_importfiles.lua
+++ b/xmake/modules/target/action/install/cmake_importfiles.lua
@@ -57,7 +57,7 @@ function _get_builtinvars(target, installdir, libdir)
raise("target(%s): libdir(%s) is not in installdir(%s)", target:name(), libdir, installdir)
end
return {LIBDIR = libsubdir,
- TARGETNAME = target:name(),
+ TARGET_NAME = target:name(),
PROJECTNAME = project.name() or target:name(),
TARGETFILENAME = target:targetfile() and _get_libfilename(target, libdir),
TARGETKIND = target:is_headeronly() and "INTERFACE" or (target:is_shared() and "SHARED" or "STATIC"),
diff --git a/xmake/scripts/cmake_importfiles/xxxConfig.cmake b/xmake/scripts/cmake_importfiles/xxxConfig.cmake
index c999bd76a..3348937a1 100644
--- a/xmake/scripts/cmake_importfiles/xxxConfig.cmake
+++ b/xmake/scripts/cmake_importfiles/xxxConfig.cmake
@@ -24,5 +24,5 @@ endmacro()
####################################################################################
-include("${CMAKE_CURRENT_LIST_DIR}/@[email protected]")
-check_required_components("@TARGETNAME@")
+include("${CMAKE_CURRENT_LIST_DIR}/@[email protected]")
+check_required_components("@TARGET_NAME@")
diff --git a/xmake/templates/c++/console/xmake.lua b/xmake/templates/c++/console/xmake.lua
index 649206eb1..c73be8724 100644
--- a/xmake/templates/c++/console/xmake.lua
+++ b/xmake/templates/c++/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/module.binary/xmake.lua b/xmake/templates/c++/module.binary/xmake.lua
index 47fed5bc6..d73d457d3 100644
--- a/xmake/templates/c++/module.binary/xmake.lua
+++ b/xmake/templates/c++/module.binary/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_moduledirs("modules")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.cpp")
on_config(function (target)
diff --git a/xmake/templates/c++/module.shared/xmake.lua b/xmake/templates/c++/module.shared/xmake.lua
index 34496aa5b..43aafe904 100644
--- a/xmake/templates/c++/module.shared/xmake.lua
+++ b/xmake/templates/c++/module.shared/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_moduledirs("modules")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.cpp")
on_config(function (target)
diff --git a/xmake/templates/c++/qt.console/xmake.lua b/xmake/templates/c++/qt.console/xmake.lua
index fc9104ce6..2ce5aa993 100644
--- a/xmake/templates/c++/qt.console/xmake.lua
+++ b/xmake/templates/c++/qt.console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.console")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.quickapp/xmake.lua b/xmake/templates/c++/qt.quickapp/xmake.lua
index 4dd4fc684..3f71d1c15 100644
--- a/xmake/templates/c++/qt.quickapp/xmake.lua
+++ b/xmake/templates/c++/qt.quickapp/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.quickapp")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.quickapp_static/xmake.lua b/xmake/templates/c++/qt.quickapp_static/xmake.lua
index 0d752b270..0d311a762 100644
--- a/xmake/templates/c++/qt.quickapp_static/xmake.lua
+++ b/xmake/templates/c++/qt.quickapp_static/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
includes("@builtin/qt")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.quickapp_static")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.shared/xmake.lua b/xmake/templates/c++/qt.shared/xmake.lua
index aa5cebf0a..3b07153b9 100644
--- a/xmake/templates/c++/qt.shared/xmake.lua
+++ b/xmake/templates/c++/qt.shared/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.shared")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.static/xmake.lua b/xmake/templates/c++/qt.static/xmake.lua
index 6ff2a8c58..371bdf082 100644
--- a/xmake/templates/c++/qt.static/xmake.lua
+++ b/xmake/templates/c++/qt.static/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.static")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.widgetapp/xmake.lua b/xmake/templates/c++/qt.widgetapp/xmake.lua
index 9fdf5206d..e0f9f455e 100644
--- a/xmake/templates/c++/qt.widgetapp/xmake.lua
+++ b/xmake/templates/c++/qt.widgetapp/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.widgetapp")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/qt.widgetapp_static/xmake.lua b/xmake/templates/c++/qt.widgetapp_static/xmake.lua
index b2cc1ac86..2c357e531 100644
--- a/xmake/templates/c++/qt.widgetapp_static/xmake.lua
+++ b/xmake/templates/c++/qt.widgetapp_static/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
includes("@builtin/qt")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("qt.widgetapp_static")
add_headerfiles("src/*.h")
add_files("src/*.cpp")
diff --git a/xmake/templates/c++/shared/xmake.lua b/xmake/templates/c++/shared/xmake.lua
index 43510f03e..96bd36d7c 100644
--- a/xmake/templates/c++/shared/xmake.lua
+++ b/xmake/templates/c++/shared/xmake.lua
@@ -4,7 +4,7 @@ target("foo")
set_kind("shared")
add_files("src/foo.cpp")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("foo")
add_files("src/main.cpp")
diff --git a/xmake/templates/c++/static/xmake.lua b/xmake/templates/c++/static/xmake.lua
index 45d81c393..2c15d36e8 100644
--- a/xmake/templates/c++/static/xmake.lua
+++ b/xmake/templates/c++/static/xmake.lua
@@ -4,7 +4,7 @@ target("foo")
set_kind("static")
add_files("src/foo.cpp")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("foo")
add_files("src/main.cpp")
diff --git a/xmake/templates/c++/wxwidgets/xmake.lua b/xmake/templates/c++/wxwidgets/xmake.lua
index 4b062189f..65a05c72c 100644
--- a/xmake/templates/c++/wxwidgets/xmake.lua
+++ b/xmake/templates/c++/wxwidgets/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_requires("wxwidgets")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.cpp")
set_languages("c++14")
diff --git a/xmake/templates/c++/xmake.cli/src/lni/main.cpp b/xmake/templates/c++/xmake.cli/src/lni/main.cpp
index e8955e074..3de2b1e36 100644
--- a/xmake/templates/c++/xmake.cli/src/lni/main.cpp
+++ b/xmake/templates/c++/xmake.cli/src/lni/main.cpp
@@ -19,5 +19,5 @@ static tb_void_t lni_initalizer(xm_engine_ref_t engine, lua_State *lua) {
tb_int_t main(tb_int_t argc, tb_char_t **argv) {
tb_char_t *taskargv[] = { "lua", "-D", "lua.main", tb_null };
- return xm_engine_run("${TARGETNAME}", argc, argv, taskargv, lni_initalizer);
+ return xm_engine_run("${TARGET_NAME}", argc, argv, taskargv, lni_initalizer);
}
diff --git a/xmake/templates/c++/xmake.cli/xmake.lua b/xmake/templates/c++/xmake.cli/xmake.lua
index 5fa81aa45..cf1987c60 100644
--- a/xmake/templates/c++/xmake.cli/xmake.lua
+++ b/xmake/templates/c++/xmake.cli/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_requires("libxmake")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xmake.cli")
add_files("src/lni/*.cpp")
add_files("src/lua/*.lua", {rootdir = "src"})
diff --git a/xmake/templates/c/console/xmake.lua b/xmake/templates/c/console/xmake.lua
index 4fe46c6ff..7e9356f26 100644
--- a/xmake/templates/c/console/xmake.lua
+++ b/xmake/templates/c/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.c")
diff --git a/xmake/templates/c/module.binary/xmake.lua b/xmake/templates/c/module.binary/xmake.lua
index fdd8bb1e5..7df556cb8 100644
--- a/xmake/templates/c/module.binary/xmake.lua
+++ b/xmake/templates/c/module.binary/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_moduledirs("modules")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.c")
on_config(function (target)
diff --git a/xmake/templates/c/module.shared/xmake.lua b/xmake/templates/c/module.shared/xmake.lua
index e39ac665d..4b92b0b9e 100644
--- a/xmake/templates/c/module.shared/xmake.lua
+++ b/xmake/templates/c/module.shared/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_moduledirs("modules")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.c")
on_config(function (target)
diff --git a/xmake/templates/c/shared/xmake.lua b/xmake/templates/c/shared/xmake.lua
index 91dac7c63..11e8dd0dd 100644
--- a/xmake/templates/c/shared/xmake.lua
+++ b/xmake/templates/c/shared/xmake.lua
@@ -4,7 +4,7 @@ target("foo")
set_kind("shared")
add_files("src/foo.c")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("foo")
add_files("src/main.c")
diff --git a/xmake/templates/c/static/xmake.lua b/xmake/templates/c/static/xmake.lua
index fd0b0592a..f00e9f4f7 100644
--- a/xmake/templates/c/static/xmake.lua
+++ b/xmake/templates/c/static/xmake.lua
@@ -4,7 +4,7 @@ target("foo")
set_kind("static")
add_files("src/foo.c")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("foo")
add_files("src/main.c")
diff --git a/xmake/templates/c/xmake.cli/src/lni/main.c b/xmake/templates/c/xmake.cli/src/lni/main.c
index a4c6499ee..1ef27cd75 100644
--- a/xmake/templates/c/xmake.cli/src/lni/main.c
+++ b/xmake/templates/c/xmake.cli/src/lni/main.c
@@ -17,5 +17,5 @@ static tb_void_t lni_initalizer(xm_engine_ref_t engine, lua_State *lua) {
tb_int_t main(tb_int_t argc, tb_char_t **argv) {
tb_char_t *taskargv[] = { "lua", "-D", "lua.main", tb_null };
- return xm_engine_run("${TARGETNAME}", argc, argv, taskargv, lni_initalizer);
+ return xm_engine_run("${TARGET_NAME}", argc, argv, taskargv, lni_initalizer);
}
diff --git a/xmake/templates/c/xmake.cli/xmake.lua b/xmake/templates/c/xmake.cli/xmake.lua
index 678c5ba3a..33422b5c0 100644
--- a/xmake/templates/c/xmake.cli/xmake.lua
+++ b/xmake/templates/c/xmake.cli/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_requires("libxmake")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xmake.cli")
add_files("src/lni/*.c")
add_files("src/lua/*.lua", {rootdir = "src"})
diff --git a/xmake/templates/cuda/console/xmake.lua b/xmake/templates/cuda/console/xmake.lua
index 5cfdad354..fb393bab7 100644
--- a/xmake/templates/cuda/console/xmake.lua
+++ b/xmake/templates/cuda/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.cu")
diff --git a/xmake/templates/cuda/shared/xmake.lua b/xmake/templates/cuda/shared/xmake.lua
index 45c27363f..5f53ff87b 100644
--- a/xmake/templates/cuda/shared/xmake.lua
+++ b/xmake/templates/cuda/shared/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("shared")
add_files("src/**.cu")
add_includedirs("inc")
diff --git a/xmake/templates/cuda/static/xmake.lua b/xmake/templates/cuda/static/xmake.lua
index 6d84c3b92..7a582cfbb 100644
--- a/xmake/templates/cuda/static/xmake.lua
+++ b/xmake/templates/cuda/static/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("static")
add_files("src/**.cu")
add_includedirs("inc")
diff --git a/xmake/templates/dlang/console/xmake.lua b/xmake/templates/dlang/console/xmake.lua
index 86ace289d..c242d60c2 100644
--- a/xmake/templates/dlang/console/xmake.lua
+++ b/xmake/templates/dlang/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.d")
diff --git a/xmake/templates/dlang/shared/xmake.lua b/xmake/templates/dlang/shared/xmake.lua
index b9cc7cb8f..0086bebae 100644
--- a/xmake/templates/dlang/shared/xmake.lua
+++ b/xmake/templates/dlang/shared/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("shared")
add_files("src/interfaces.d")
add_includedirs("src", {public = true})
@@ -8,9 +8,9 @@ target("${TARGETNAME}")
"add",
"sub"}})
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.d")
${FAQ}
diff --git a/xmake/templates/dlang/static/xmake.lua b/xmake/templates/dlang/static/xmake.lua
index ba4d99e77..b8fb24b37 100644
--- a/xmake/templates/dlang/static/xmake.lua
+++ b/xmake/templates/dlang/static/xmake.lua
@@ -1,13 +1,13 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("static")
add_files("src/interfaces.d")
add_includedirs("src", {public = true})
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.d")
${FAQ}
diff --git a/xmake/templates/fortran/console/xmake.lua b/xmake/templates/fortran/console/xmake.lua
index b12d74cce..70faf8aea 100644
--- a/xmake/templates/fortran/console/xmake.lua
+++ b/xmake/templates/fortran/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.f90")
diff --git a/xmake/templates/fortran/shared/xmake.lua b/xmake/templates/fortran/shared/xmake.lua
index 04bf17567..da6d6da3f 100644
--- a/xmake/templates/fortran/shared/xmake.lua
+++ b/xmake/templates/fortran/shared/xmake.lua
@@ -1,11 +1,11 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}_lib")
+target("${TARGET_NAME}_lib")
set_kind("shared")
add_files("src/test.f90")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
- add_deps("${TARGETNAME}_lib")
+ add_deps("${TARGET_NAME}_lib")
add_files("src/main.f90")
diff --git a/xmake/templates/fortran/static/xmake.lua b/xmake/templates/fortran/static/xmake.lua
index 694c1d390..4b91ad207 100644
--- a/xmake/templates/fortran/static/xmake.lua
+++ b/xmake/templates/fortran/static/xmake.lua
@@ -1,11 +1,11 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}_lib")
+target("${TARGET_NAME}_lib")
set_kind("static")
add_files("src/test.f90")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
- add_deps("${TARGETNAME}_lib")
+ add_deps("${TARGET_NAME}_lib")
add_files("src/main.f90")
diff --git a/xmake/templates/go/console/xmake.lua b/xmake/templates/go/console/xmake.lua
index 09355a74b..a7861eb2a 100644
--- a/xmake/templates/go/console/xmake.lua
+++ b/xmake/templates/go/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.go")
diff --git a/xmake/templates/go/static/xmake.lua b/xmake/templates/go/static/xmake.lua
index 076ac6460..4391d7799 100644
--- a/xmake/templates/go/static/xmake.lua
+++ b/xmake/templates/go/static/xmake.lua
@@ -4,7 +4,7 @@ target("module")
set_kind("static")
add_files("src/module/*.go")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
add_deps("module")
add_files("src/*.go")
diff --git a/xmake/templates/kotlin/console/xmake.lua b/xmake/templates/kotlin/console/xmake.lua
index 2689995b1..935dc7c75 100644
--- a/xmake/templates/kotlin/console/xmake.lua
+++ b/xmake/templates/kotlin/console/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_requires("kotlin-native")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/main.kt")
set_toolchains("@kotlin-native")
diff --git a/xmake/templates/kotlin/shared/xmake.lua b/xmake/templates/kotlin/shared/xmake.lua
index 491a8f835..97bebf8a6 100644
--- a/xmake/templates/kotlin/shared/xmake.lua
+++ b/xmake/templates/kotlin/shared/xmake.lua
@@ -5,7 +5,7 @@ target("foo")
add_files("src/foo.kt")
set_toolchains("@kotlin-native")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/main.c")
add_deps("foo")
diff --git a/xmake/templates/kotlin/static/xmake.lua b/xmake/templates/kotlin/static/xmake.lua
index 2667c26fd..6095dbe93 100644
--- a/xmake/templates/kotlin/static/xmake.lua
+++ b/xmake/templates/kotlin/static/xmake.lua
@@ -5,7 +5,7 @@ target("foo")
add_files("src/foo.kt")
set_toolchains("@kotlin-native")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/main.c")
add_deps("foo")
diff --git a/xmake/templates/nim/console/xmake.lua b/xmake/templates/nim/console/xmake.lua
index f41148c2f..662945bbb 100644
--- a/xmake/templates/nim/console/xmake.lua
+++ b/xmake/templates/nim/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/main.nim")
diff --git a/xmake/templates/nim/shared/xmake.lua b/xmake/templates/nim/shared/xmake.lua
index e2d380ac6..5067dafb3 100644
--- a/xmake/templates/nim/shared/xmake.lua
+++ b/xmake/templates/nim/shared/xmake.lua
@@ -1,12 +1,12 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("shared")
add_files("src/foo.nim")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.nim")
${FAQ}
diff --git a/xmake/templates/nim/static/xmake.lua b/xmake/templates/nim/static/xmake.lua
index cf70acb9e..3f2cb7dfc 100644
--- a/xmake/templates/nim/static/xmake.lua
+++ b/xmake/templates/nim/static/xmake.lua
@@ -1,12 +1,12 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("static")
add_files("src/foo.nim")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.nim")
${FAQ}
diff --git a/xmake/templates/objc++/console/xmake.lua b/xmake/templates/objc++/console/xmake.lua
index f99120596..99749f901 100644
--- a/xmake/templates/objc++/console/xmake.lua
+++ b/xmake/templates/objc++/console/xmake.lua
@@ -2,7 +2,7 @@
add_rules("mode.debug", "mode.release")
-- add target
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
-- set kind
set_kind("binary")
diff --git a/xmake/templates/objc++/xcode.bundle/xmake.lua b/xmake/templates/objc++/xcode.bundle/xmake.lua
index 364e27278..1ecf69fcb 100644
--- a/xmake/templates/objc++/xcode.bundle/xmake.lua
+++ b/xmake/templates/objc++/xcode.bundle/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.bundle")
add_files("src/*.mm")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc++/xcode.framework/xmake.lua b/xmake/templates/objc++/xcode.framework/xmake.lua
index db61439df..3805d95c6 100644
--- a/xmake/templates/objc++/xcode.framework/xmake.lua
+++ b/xmake/templates/objc++/xcode.framework/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.framework")
add_files("src/*.mm")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc/console/xmake.lua b/xmake/templates/objc/console/xmake.lua
index 75496210f..37c01442a 100644
--- a/xmake/templates/objc/console/xmake.lua
+++ b/xmake/templates/objc/console/xmake.lua
@@ -2,7 +2,7 @@
add_rules("mode.debug", "mode.release")
-- add target
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
-- set kind
set_kind("binary")
diff --git a/xmake/templates/objc/xcode.bundle/xmake.lua b/xmake/templates/objc/xcode.bundle/xmake.lua
index 088994340..34d108fcb 100644
--- a/xmake/templates/objc/xcode.bundle/xmake.lua
+++ b/xmake/templates/objc/xcode.bundle/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.bundle")
add_files("src/*.m")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc/xcode.framework/xmake.lua b/xmake/templates/objc/xcode.framework/xmake.lua
index ad8e30290..83ddfa1a2 100644
--- a/xmake/templates/objc/xcode.framework/xmake.lua
+++ b/xmake/templates/objc/xcode.framework/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.framework")
add_files("src/*.m")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc/xcode.iosapp/xmake.lua b/xmake/templates/objc/xcode.iosapp/xmake.lua
index b5b00b81f..1306fce94 100644
--- a/xmake/templates/objc/xcode.iosapp/xmake.lua
+++ b/xmake/templates/objc/xcode.iosapp/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.application")
add_files("src/*.m", "src/**.storyboard", "src/*.xcassets")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc/xcode.iosapp_with_framework/xmake.lua b/xmake/templates/objc/xcode.iosapp_with_framework/xmake.lua
index 89348a3b6..e1383b8b2 100644
--- a/xmake/templates/objc/xcode.iosapp_with_framework/xmake.lua
+++ b/xmake/templates/objc/xcode.iosapp_with_framework/xmake.lua
@@ -6,7 +6,7 @@ target("test")
add_files("src/framework/Info.plist")
add_headerfiles("src/framework/test.h")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.application")
add_deps("test")
add_files("src/app/*.m", "src/app/**.storyboard", "src/app/*.xcassets")
diff --git a/xmake/templates/objc/xcode.macapp/xmake.lua b/xmake/templates/objc/xcode.macapp/xmake.lua
index b5b00b81f..1306fce94 100644
--- a/xmake/templates/objc/xcode.macapp/xmake.lua
+++ b/xmake/templates/objc/xcode.macapp/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.application")
add_files("src/*.m", "src/**.storyboard", "src/*.xcassets")
add_files("src/Info.plist")
diff --git a/xmake/templates/objc/xcode.macapp_with_framework/xmake.lua b/xmake/templates/objc/xcode.macapp_with_framework/xmake.lua
index 89348a3b6..e1383b8b2 100644
--- a/xmake/templates/objc/xcode.macapp_with_framework/xmake.lua
+++ b/xmake/templates/objc/xcode.macapp_with_framework/xmake.lua
@@ -6,7 +6,7 @@ target("test")
add_files("src/framework/Info.plist")
add_headerfiles("src/framework/test.h")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
add_rules("xcode.application")
add_deps("test")
add_files("src/app/*.m", "src/app/**.storyboard", "src/app/*.xcassets")
diff --git a/xmake/templates/pascal/console/xmake.lua b/xmake/templates/pascal/console/xmake.lua
index 155005840..52168c3a4 100644
--- a/xmake/templates/pascal/console/xmake.lua
+++ b/xmake/templates/pascal/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.pas")
diff --git a/xmake/templates/pascal/shared/xmake.lua b/xmake/templates/pascal/shared/xmake.lua
index dd29cf486..fad68bd07 100644
--- a/xmake/templates/pascal/shared/xmake.lua
+++ b/xmake/templates/pascal/shared/xmake.lua
@@ -3,7 +3,7 @@ target("foo")
set_kind("shared")
add_files("src/foo.pas")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("foo")
add_files("src/main.pas")
diff --git a/xmake/templates/rust/console/xmake.lua b/xmake/templates/rust/console/xmake.lua
index 2d0e19145..684ea720a 100644
--- a/xmake/templates/rust/console/xmake.lua
+++ b/xmake/templates/rust/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/main.rs")
diff --git a/xmake/templates/rust/shared/xmake.lua b/xmake/templates/rust/shared/xmake.lua
index d20b6f5d7..52effc17b 100644
--- a/xmake/templates/rust/shared/xmake.lua
+++ b/xmake/templates/rust/shared/xmake.lua
@@ -2,7 +2,7 @@ target("foo")
set_kind("shared")
add_files("src/foo.rs")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
add_deps("foo")
add_files("src/main.rs")
diff --git a/xmake/templates/rust/static/xmake.lua b/xmake/templates/rust/static/xmake.lua
index 79a9ac569..9eb48bef1 100644
--- a/xmake/templates/rust/static/xmake.lua
+++ b/xmake/templates/rust/static/xmake.lua
@@ -2,7 +2,7 @@ target("foo")
set_kind("static")
add_files("src/foo.rs")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
add_deps("foo")
add_files("src/main.rs")
diff --git a/xmake/templates/swift/console/xmake.lua b/xmake/templates/swift/console/xmake.lua
index f607b1127..d07f6547b 100644
--- a/xmake/templates/swift/console/xmake.lua
+++ b/xmake/templates/swift/console/xmake.lua
@@ -2,7 +2,7 @@
add_rules("mode.debug", "mode.release")
-- add target
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
-- set kind
set_kind("binary")
diff --git a/xmake/templates/vala/console/xmake.lua b/xmake/templates/vala/console/xmake.lua
index 474572597..4fb124a8a 100644
--- a/xmake/templates/vala/console/xmake.lua
+++ b/xmake/templates/vala/console/xmake.lua
@@ -2,7 +2,7 @@ add_rules("mode.debug", "mode.release")
add_requires("lua", "glib")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_rules("vala")
add_files("src/*.vala")
diff --git a/xmake/templates/vala/shared/xmake.lua b/xmake/templates/vala/shared/xmake.lua
index e9148106c..4b4291a78 100644
--- a/xmake/templates/vala/shared/xmake.lua
+++ b/xmake/templates/vala/shared/xmake.lua
@@ -10,7 +10,7 @@ target("mymath")
add_values("vala.vapi", "mymath-1.0.vapi")
add_packages("glib")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("mymath")
add_rules("vala")
diff --git a/xmake/templates/vala/static/xmake.lua b/xmake/templates/vala/static/xmake.lua
index 143566fcb..8e2430db7 100644
--- a/xmake/templates/vala/static/xmake.lua
+++ b/xmake/templates/vala/static/xmake.lua
@@ -10,7 +10,7 @@ target("mymath")
add_values("vala.vapi", "mymath-1.0.vapi")
add_packages("glib")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_deps("mymath")
add_rules("vala")
diff --git a/xmake/templates/zig/console/xmake.lua b/xmake/templates/zig/console/xmake.lua
index 69a4b4477..28940257d 100644
--- a/xmake/templates/zig/console/xmake.lua
+++ b/xmake/templates/zig/console/xmake.lua
@@ -1,6 +1,6 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("binary")
add_files("src/*.zig")
diff --git a/xmake/templates/zig/shared/xmake.lua b/xmake/templates/zig/shared/xmake.lua
index a21b056bc..2577bde9f 100644
--- a/xmake/templates/zig/shared/xmake.lua
+++ b/xmake/templates/zig/shared/xmake.lua
@@ -1,12 +1,12 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("shared")
add_files("src/test.zig")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.zig")
${FAQ}
diff --git a/xmake/templates/zig/static/xmake.lua b/xmake/templates/zig/static/xmake.lua
index f1321ee0f..2cc6601d2 100644
--- a/xmake/templates/zig/static/xmake.lua
+++ b/xmake/templates/zig/static/xmake.lua
@@ -1,12 +1,12 @@
add_rules("mode.debug", "mode.release")
-target("${TARGETNAME}")
+target("${TARGET_NAME}")
set_kind("static")
add_files("src/test.zig")
-target("${TARGETNAME}_demo")
+target("${TARGET_NAME}_demo")
set_kind("binary")
- add_deps("${TARGETNAME}")
+ add_deps("${TARGET_NAME}")
add_files("src/main.zig")
${FAQ}
diff --git a/xmake/scripts/cmake_importfiles/xxxTargets-debug.cmake b/xmake/scripts/cmake_importfiles/xxxTargets-debug.cmake
index d0f387f63..5d655c953 100644
--- a/xmake/scripts/cmake_importfiles/xxxTargets-debug.cmake
+++ b/xmake/scripts/cmake_importfiles/xxxTargets-debug.cmake
@@ -5,16 +5,16 @@
# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)
-# Import target "@PROJECTNAME@::@TARGETNAME@" for configuration "Debug"
-set_property(TARGET @PROJECTNAME@::@TARGETNAME@ APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
-set_target_properties(@PROJECTNAME@::@TARGETNAME@ PROPERTIES
+# Import target "@PROJECTNAME@::@TARGET_NAME@" for configuration "Debug"
+set_property(TARGET @PROJECTNAME@::@TARGET_NAME@ APPEND PROPERTY IMPORTED_CONFIGURATIONS DEBUG)
+set_target_properties(@PROJECTNAME@::@TARGET_NAME@ PROPERTIES
IMPORTED_LINK_INTERFACE_LANGUAGES_DEBUG "ASM_NASM;C"
# IMPORTED_IMPLIB_DEBUG "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@"
IMPORTED_LOCATION_DEBUG "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@"
)
-list(APPEND _IMPORT_CHECK_TARGETS @PROJECTNAME@::@TARGETNAME@ )
-list(APPEND _IMPORT_CHECK_FILES_FOR_@PROJECTNAME@::@TARGETNAME@ "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@" )
+list(APPEND _IMPORT_CHECK_TARGETS @PROJECTNAME@::@TARGET_NAME@ )
+list(APPEND _IMPORT_CHECK_FILES_FOR_@PROJECTNAME@::@TARGET_NAME@ "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@" )
# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
diff --git a/xmake/scripts/cmake_importfiles/xxxTargets-release.cmake b/xmake/scripts/cmake_importfiles/xxxTargets-release.cmake
index c42d48316..9fb36cc2b 100644
--- a/xmake/scripts/cmake_importfiles/xxxTargets-release.cmake
+++ b/xmake/scripts/cmake_importfiles/xxxTargets-release.cmake
@@ -5,16 +5,16 @@
# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)
-# Import target "@PROJECTNAME@::@TARGETNAME@" for configuration "Release"
-set_property(TARGET @PROJECTNAME@::@TARGETNAME@ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
-set_target_properties(@PROJECTNAME@::@TARGETNAME@ PROPERTIES
+# Import target "@PROJECTNAME@::@TARGET_NAME@" for configuration "Release"
+set_property(TARGET @PROJECTNAME@::@TARGET_NAME@ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
+set_target_properties(@PROJECTNAME@::@TARGET_NAME@ PROPERTIES
IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "ASM_NASM;C"
# IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@"
IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@"
)
-list(APPEND _IMPORT_CHECK_TARGETS @PROJECTNAME@::@TARGETNAME@ )
-list(APPEND _IMPORT_CHECK_FILES_FOR_@PROJECTNAME@::@TARGETNAME@ "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@" )
+list(APPEND _IMPORT_CHECK_TARGETS @PROJECTNAME@::@TARGET_NAME@ )
+list(APPEND _IMPORT_CHECK_FILES_FOR_@PROJECTNAME@::@TARGET_NAME@ "${_IMPORT_PREFIX}/@LIBDIR@/@TARGETFILENAME@" )
# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
diff --git a/xmake/scripts/cmake_importfiles/xxxTargets.cmake b/xmake/scripts/cmake_importfiles/xxxTargets.cmake
index bdf2774e9..1bbc0d85e 100644
--- a/xmake/scripts/cmake_importfiles/xxxTargets.cmake
+++ b/xmake/scripts/cmake_importfiles/xxxTargets.cmake
@@ -16,7 +16,7 @@ set(CMAKE_IMPORT_FILE_VERSION 1)
set(_targetsDefined)
set(_targetsNotDefined)
set(_expectedTargets)
-foreach(_expectedTarget @PROJECTNAME@::@TARGETNAME@)
+foreach(_expectedTarget @PROJECTNAME@::@TARGET_NAME@)
list(APPEND _expectedTargets ${_expectedTarget})
if(NOT TARGET ${_expectedTarget})
list(APPEND _targetsNotDefined ${_expectedTarget})
@@ -49,16 +49,16 @@ if (_IMPORT_PREFIX STREQUAL "/")
set(_IMPORT_PREFIX "")
endif()
-# Create imported target @PROJECTNAME@::@TARGETNAME@
-add_library(@PROJECTNAME@::@TARGETNAME@ @TARGETKIND@ IMPORTED)
+# Create imported target @PROJECTNAME@::@TARGET_NAME@
+add_library(@PROJECTNAME@::@TARGET_NAME@ @TARGETKIND@ IMPORTED)
-set_target_properties(@PROJECTNAME@::@TARGETNAME@ PROPERTIES
+set_target_properties(@PROJECTNAME@::@TARGET_NAME@ PROPERTIES
INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include"
)
# Load information for each installed configuration.
get_filename_component(_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)
-file(GLOB CONFIG_FILES "${_DIR}/@TARGETNAME@Targets-*.cmake")
+file(GLOB CONFIG_FILES "${_DIR}/@TARGET_NAME@Targets-*.cmake")
foreach(f ${CONFIG_FILES})
include(${f})
endforeach()